summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/knewstuff/provider.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/knewstuff/provider.h')
-rw-r--r--lib/compatibility/knewstuff/provider.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/lib/compatibility/knewstuff/provider.h b/lib/compatibility/knewstuff/provider.h
index f878175a..43ff5fc2 100644
--- a/lib/compatibility/knewstuff/provider.h
+++ b/lib/compatibility/knewstuff/provider.h
@@ -144,7 +144,7 @@ class Provider
protected:
void parseDomElement( const TQDomElement & );
- TQDomElement createDomElement( TQDomDocument &, TQDomElement &parent );
+ TQDomElement createDomElement( TQDomDocument &, TQDomElement &tqparent );
private:
TQString mName;
@@ -161,16 +161,17 @@ class Provider
* the main provider database for this specific application.
* It should probably not be used directly by the application.
*/
-class ProviderLoader : public QObject
+class ProviderLoader : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
*
* @param parentWidget the parent widget
*/
- ProviderLoader( TQWidget *parentWidget );
+ ProviderLoader( TQWidget *tqparentWidget );
/**
* Starts asynchronously loading the list of providers of the
@@ -181,7 +182,7 @@ class ProviderLoader : public QObject
* we first try the ProvidersUrl from KGlobal::config, then we
* fall back to a hardcoded value.
*/
- void load( const TQString &type, const TQString &providerList = TQString::null );
+ void load( const TQString &type, const TQString &providerList = TQString() );
signals:
/**
@@ -161,16 +161,17 @@ class Provider
* Constructor.
*
- * @param parentWidget the parent widget
+ * @param tqparentWidget the tqparent widget
*/